@@ -22,6 +22,7 @@ from singer import utils
 from singer.catalog import Catalog, CatalogEntry
 from singer.schema import Schema
 
+from macrometa_source_snowflake.sync_strategies.sample_data import fetch_samples
 import macrometa_source_snowflake.sync_strategies.common as common
 import macrometa_source_snowflake.sync_strategies.full_table as full_table
 import macrometa_source_snowflake.sync_strategies.incremental as incremental
@@ -558,12 +559,47 @@ class SnowflakeSourceConnector(C8Connector):
     # TODO: Need to add handling of reserved keys
     def samples(self, integration: dict) -> list[Sample]:
         """Fetch sample data using the provided configurations."""
-        return []
+        config = self.get_config(integration)
+        try:
+            snowflake_conn = SnowflakeConnection(config)
+            catalog = do_discover(snowflake_conn, config)
+            results = []
+            for stream in catalog.streams:
+                s_attribs = []
+                s_schema = stream.schema
+                data = fetch_samples(config, stream)[:10]
+                for k, v in s_schema.properties.items():
+                    t = v['type'][-1]
+                    s_attribs.append(SchemaAttribute(
+                        k, self.get_attribute_type(t)))
+                schema = Schema(stream.stream, s_attribs)
+                results.append(Sample(
+                    schema=schema,
+                    data=data)
+                )
+        except Exception as e:
+            raise e
+        return results
 
     # TODO: Need to add handling of reserved keys
     def schemas(self, integration: dict) -> list[Schema]:
         """Get supported schemas using the given configurations."""
-        return []
+        config = self.get_config(integration)
+        try:
+            snowflake_conn = SnowflakeConnection(config)
+            catalog = do_discover(snowflake_conn, config)
+            results = []
+            for stream in catalog.streams:
+                s_attribs = []
+                s_schema = stream.schema
+                for k, v in s_schema.properties.items():
+                    t = v['type'][-1]
+                    s_attribs.append(SchemaAttribute(
+                        k, self.get_attribute_type(t)))
+                results.append(Schema(stream.stream, s_attribs))
+        except Exception as e:
+            raise e
+        return results
 
     def reserved_keys(self) -> list[str]:
         """List of reserved keys for the connector."""
